=============
Basket Client
=============

This is a client for Mozilla's email subscription service,
basket. Basket is not a real subscription service, but it talks to a
real one and we don't really care who/what it is.

.. image:: https://circleci.com/gh/mozilla/basket-client/tree/master.svg?style=svg
    :target: https://circleci.com/gh/mozilla/basket-client/tree/master
.. image:: https://pypip.in/v/basket-client/badge.png
    :target: https://crate.io/packages/basket-client


Docs
----

Documentation can be found at http://basket-client.rtfd.org/


License
-------
This software is licensed under the MPL http://www.mozilla.org/MPL/. For more
information, read the file ``LICENSE``.
